@@ -2,79 +2,81 @@
 internationalization / localization helpers
 ===========================================
 
-On importing this portion it will automatically determine the default locale (language) and encoding of your operating
+on importing this portion it will automatically determine the default locale (language) and encoding of your operating
 system and user configuration.
 
-The functions :func:`default_language` and :func:`default_encoding` - provided by this portion - are determining or
+the functions :func:`default_language` and :func:`default_encoding` - provided by this portion - are determining or
 changing the default language and translation texts encoding.
 
-Additional languages will be automatically loaded by the function :func:`load_language_texts`.
+additional languages will be automatically loaded by the function :func:`load_language_texts`.
 
 
 translation texts locale paths
 ------------------------------
 
-Locale paths can be provided by your app as well as any python package and namespace portion. By default they are
-situated in a sub-folder with the name `loc` underneath of your app/package root folder. For to add them for a package
-simply call the function :func:`register_package_translations`, which is also used by some ae namespace portions (e.g.
-:mod:`ae.gui_help`) for to include package/module specific translation messages.
+multiple paths can be provided by your app as well as any python package and namespace portion to store translation
+texts. by default they are situated in a sub-folder with the name `loc` underneath of your app/package root folder. to
+load them call the function :func:`register_package_translations` from the module using the locale texts.
+
+.. hint:: see e.g. the ae namespace portion :mod:`ae.gui_help` loading package/module specific translation messages.
 
 .. hint::
-    The :meth:`~ae.gui_app.on_app_build` app event is used by :mod:`~ae.gui_help` for to load the app-specific
-    translation texts on app startup.
+    the :meth:`~ae.gui_app.on_app_build` app event is used by :mod:`~ae.gui_help` to load the app-specific translation
+    texts on app startup.
 
-For to specify additional locale folders you can use the function :func:`register_translations_path`.
+to specify additional locale folders you can use the function :func:`register_translations_path`.
 
-In a locale folder have to exist at least one sub-folder with a name of the language code for each supported language
+in a locale folder have to exist at least one sub-folder with a name of the language code for each supported language
 (e.g. 'loc/en' for english).
 
-In each of these sub-folders there have to be at least one message translation file with a file name ending in the
-string specified by the constant :data:`MSG_FILE_SUFFIX`).
+in each of these sub-folders at least one message translation file with a file name ending in the string specified by
+the constant :data:`MSG_FILE_SUFFIX` has to exist.
 
 
 translatable message texts and f-strings
 ----------------------------------------
 
-Simple message texts can be enclosed in the code of your application with the
-:func:`get_text` function provided by this portion/module::
+simple message text strings can be enclosed in the code of your application with the :func:`get_text` function provided
+by this portion/module::
 
     from ae.i18n import get_text
 
     message = get_text("any translatable message displayed to the app user.")
     print(message)          # prints the translated message text
 
-For more complex messages with placeholders you can use the :func:`get_f_string`
-function::
+for more complex messages with placeholders you can use the :func:`get_f_string` function::
 
     from ae.i18n import get_f_string
 
     my_var = 69
     print(get_f_string("The value of my_var is {my_var}."))
 
-Translatable message can also be provided in various pluralization forms.
-For to get a pluralized message you have to pass the :paramref:`~get_text.count`
-keyword argument of :func:`get_text`::
+translatable message can also be provided in various pluralization forms. to get a pluralized message you have to pass
+the :paramref:`~get_text.count` keyword argument of :func:`get_text`::
 
     print(get_text("child", count=1))     # translated into "child" (in english) or e.g. "Kind" in german
     print(get_text("child", count=3))     # -> "children" (in english) or e.g. "Kinder" (in german)
 
-For pluralized message translated by the :func:`get_f_string` function, the count value have to
-be passed in the `count` item of the :paramref:`~get_f_string.loc_vars`::
+for pluralized message translated by the :func:`get_f_string` function, the count value have to be passed in the `count`
+item of the :paramref:`~get_f_string.loc_vars`::
 
     print(get_f_string("you have {count] children", loc_vars=dict(count=1)))
     # -> "you have 1 child" or e.g. "Sie haben 1 Kind"
     print(get_f_string("you have {count] children", loc_vars={'count': 3}))
     # -> "you have 3 children" or "Sie haben 3 Kinder"
 
-You can load several languages into your app run-time. For to get the translation for a language
-that is not the current default language you have to pass the :paramref:`~get_text.language` keyword argument
-with the desired language code onto the call of :func:`get_text` (or :func:`get_f_string`)::
+you can load several languages into your app run-time. to get the translation for a language that is not the current
+default language you have to pass the :paramref:`~get_text.language` keyword argument with the desired language code
+onto the call of :func:`get_text` (or :func:`get_f_string`)::
 
     print(get_text("message", language='es'))   # returns the spanish translation text of "message"
     print(get_text("message", language='de'))   # returns the german translation text of "message"
 
-The helper function :func:`translation` can be used for to determine if a translation exists for
-a message text.
+the helper function :func:`translation` can be used to determine if a translation exists for a message text.
+
+.. hint::
+    the ae portion :mod:`ae.kivy_app` is implementing translation messages for kv files and provides additional
+    helper functions and methods.
 """
 import ast
 import locale
@@ -87,7 +89,7 @@ from ae.paths import norm_path, Collector
 from ae.inspector import stack_var, stack_vars, try_eval                        # type: ignore
 
 
-__version__ = '0.1.21'
+__version__ = '0.1.22'
 
 
 MsgType = Union[str, Dict[str, str]]                        #: type of message literals in translation text files
@@ -103,7 +105,7 @@ LOADED_TRANSLATIONS: Dict[str, LanguageMessages] = dict()   #: message text tran
 
 MSG_FILE_SUFFIX = 'Msg.txt'                                 #: name suffix of translation text files
 
-TRANSLATIONS_PATHS: List[str] = list()                      #: file paths for to search for translations
+TRANSLATIONS_PATHS: List[str] = list()                      #: file paths to search for translations
 
 
 if os_platform == 'android':                                                                        # pragma: no cover
@@ -136,7 +138,7 @@ del _LANG, _ENC
 def default_encoding(new_enc: str = '') -> str:
     """ get and optionally set the default message text encoding.
 
-    :param new_enc:             new default encoding to be set. Kept unchanged if not passed.
+    :param new_enc:             new default encoding to be set. kept unchanged if not passed.
     :return:                    old default encoding (current if :paramref:`~default_encoding.new_enc` get not passed).
     """
     old_enc = default_locale[1]
@@ -148,7 +150,7 @@ def default_encoding(new_enc: str = '') -> str:
 def default_language(new_lang: str = '') -> str:
     """ get and optionally set the default language code.
 
-    :param new_lang:            new default language code to be set. Kept unchanged if not passed.
+    :param new_lang:            new default language code to be set. kept unchanged if not passed.
     :return:                    old default language (or current one if :paramref:`~default_language.new_lang`
                                 get not passed).
     """
@@ -164,13 +166,12 @@ def get_text(text: str, count: Optional[int] = None, key_suffix: str = '', langu
     """ translate passed text string into the current language.
 
     :param text:                text message to be translated.
-    :param count:               pass int value if the translated text has variants for their pluralization.
-                                The count value will be converted into an amount/pluralize key by the
-                                function :func:`plural_key`.
+    :param count:               pass int value if the translated text has variants for their pluralization. the count
+                                value will be converted into an amount/pluralize key by the function :func:`plural_key`.
     :param key_suffix:          suffix to the key used if the translation is a dict.
     :param language:            language code to load (def=current language code in 1st item of :data:`default_locale`).
-    :return:                    translated text message or the value passed into :paramref:`~get_text.text`
-                                if no translation text got found for the current language.
+    :return:                    translated text message or the value passed into :paramref:`~get_text.text` if no
+                                translation text got found for the current language.
     """
     trans = translation(text, language=language)
     if isinstance(trans, str):
@@ -188,19 +189,18 @@ def get_f_string(f_str: str, key_suffix: str = '', language: str = '',
     :param f_str:               f-string to be translated and evaluated.
     :param key_suffix:          suffix to the key used if the translation is a dict.
     :param language:            language code to load (def=current language code in 1st item of :data:`default_locale`).
-    :param glo_vars:            global variables used in the conversion of the f-string expression to a string.
-                                The globals() of the caller of the callee will be available too and get overwritten
-                                by the items of this argument.
-    :param loc_vars:            local variables used in the conversion of the f-string expression to a string.
-                                The locals() of the caller of the callee will be available too and get overwritten
-                                by the items of this argument.
-                                Pass a numeric value in the `count` item of this dict for pluralized translated texts
-                                (see also :paramref:`~get_text.count` parameter of the function :func:`get_text`).
-    :return:                    translated text message or the evaluated string result of the expression passed into
-                                :paramref:`~get_f_string.f_str` if no translation text got found for the current
-                                language. Any syntax errors and exceptions occurring in the conversion of the f-string
-                                will be ignored and the original or translated f_string value will be returned in
-                                these cases.
+    :param glo_vars:            global variables used in the conversion of the f-string expression to a string. the
+                                globals() of the caller of the callee will be available too and get overwritten by the
+                                items of this argument.
+    :param loc_vars:            local variables used in the conversion of the f-string expression to a string. the
+                                locals() of the caller of the callee will be available too and get overwritten by the
+                                items of this argument. pass a numeric value in the `count` item of this dict for
+                                pluralized translated texts (see also :paramref:`~get_text.count` parameter of the
+                                function :func:`get_text`).
+    :return:                    translated text message including evaluated and formatted variables/expressions of the
+                                f-string passed-in :paramref:`~get_f_string.f_str`. if no translation text got found for
+                                the current language then the original text message will be returned. any syntax errors
+                                and exceptions occurring in the conversion of the f-string are silently ignored.
     """
     count = loc_vars.get('count') if isinstance(loc_vars, dict) else None
     f_str = get_text(f_str, count=count, key_suffix=key_suffix, language=language)
@@ -221,7 +221,7 @@ def get_f_string(f_str: str, key_suffix: str = '', language: str = '',
 def load_language_file(file_name: str, encoding: str, language: str):
     """ load file content encoded with the given encoding into the specified language.
 
-    :param file_name:           file name (incl. path and extension to load.
+    :param file_name:           file name, inclusive path and extension to load.
     :param encoding:            encoding id string.
     :param language:            language id string.
     """
@@ -237,13 +237,12 @@ def load_language_file(file_name: str, encoding: str, language: str):
 def load_language_texts(language: str = '', encoding: str = '', domain: str = '', reset: bool = False) -> str:
     """ load translation texts for the given language and optional domain.
 
-    :param language:            language code of the translation texts to load. If not passed then use the default
-                                language.
-    :param encoding:            encoding to use for to load message file.
-    :param domain:              optional domain id, e.g. the id of an app, attached process or a user. if passed
-                                then it will be used as prefix for the message file name to be loaded additionally and
-                                after the default translation texts get loaded (overwriting the default translations).
-    :param reset:               pass True for to clear all previously added language/locale messages.
+    :param language:            language code of the translation texts to load. use the default language if not passed.
+    :param encoding:            encoding to use to load message file.
+    :param domain:              optional domain id, e.g. the id of an app, attached process or a user. if passed then it
+                                will be used as prefix for the message file name to be loaded additionally and after the
+                                default translation texts get loaded (overwriting the default translations).
+    :param reset:               pass True to clear all previously added language/locale messages.
     :return:                    language code of the loaded/default language.
     """
     global LOADED_TRANSLATIONS
@@ -267,7 +266,7 @@ def load_language_texts(language: str = '', encoding: str = '', domain: str = ''
 
 
 def plural_key(count: Optional[int]) -> str:
-    """ convert number in count into a dict key for to access the correct plural form.
+    """ convert number in :paramref:`~plural_key.count` into a dict key to access the correct plural form.
 
     :param count:               number of items used in the current context or None (resulting in empty string).
     :return:                    dict key (prefix) within the MsgType part of the translation data structure.
@@ -287,14 +286,14 @@ def plural_key(count: Optional[int]) -> str:
 
 
 def register_package_translations():
-    """ call from module scope of the package for to register/add translations resources path.
+    """ call from module scope of the package to register/add translations resources path.
 
-    No parameters needed because we use here :func:`~ae.inspector.stack_var` helper function for to determine the
-    the module file path via the `__file__` module variable of the caller module in the call stack. In this call
+    no parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
+    the module file path via the `__file__` module variable of the caller module in the call stack. in this call
     we have to overwrite the default value (:data:`~ae.inspector.SKIPPED_MODULES`) of the
-    :paramref:`~ae.inspector.stack_var.skip_modules` parameter for to not skip ae portions that are providing
+    :paramref:`~ae.inspector.stack_var.skip_modules` parameter to not skip ae portions that are providing
     package resources and are listed in the :data:`~ae.inspector.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app` and
-    :mod:`ae.gui_help` (passing empty string '' for to overwrite default skip list).
+    :mod:`ae.gui_help` (passing empty string '' to overwrite default skip list).
     """
     package_path = os.path.abspath(os.path.dirname(stack_var('__file__', '')))
     register_translations_path(package_path)
